==> huaweicloudsdkddm-3.1.136-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/delete_ddm_instance_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteDdmInstanceRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'delete_dn_data': 'bool'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'delete_dn_data': 'delete_dn_data'
    }

    def __init__(self, instance_id=None, delete_dn_data=None):
        """DeleteDdmInstanceRequest

        The model defined in huaweicloud sdk

        :param instance_id: DDM实例ID。
        :type instance_id: str
        :param delete_dn_data: 是否同时删除关联后端数据库实例上存储的数据。  - 取值true：删除。 - 取值为空或false：不删除。 默认值为空。
        :type delete_dn_data: bool
        """
        
        

        self._instance_id = None
        self._delete_dn_data = None
        self.discriminator = None

        self.instance_id = instance_id
        if delete_dn_data is not None:
            self.delete_dn_data = delete_dn_data

    @property
    def instance_id(self):
        """Gets the instance_id of this DeleteDdmInstanceRequest.

        DDM实例ID。

        :return: The instance_id of this DeleteDdmInstanceRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this DeleteDdmInstanceRequest.

        DDM实例ID。

        :param instance_id: The instance_id of this DeleteDdmInstanceRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def delete_dn_data(self):
        """Gets the delete_dn_data of this DeleteDdmInstanceRequest.

        是否同时删除关联后端数据库实例上存储的数据。  - 取值true：删除。 - 取值为空或false：不删除。 默认值为空。

        :return: The delete_dn_data of this DeleteDdmInstanceRequest.
        :rtype: bool
        """
        return self._delete_dn_data

    @delete_dn_data.setter
    def delete_dn_data(self, delete_dn_data):
        """Sets the delete_dn_data of this DeleteDdmInstanceRequest.

        是否同时删除关联后端数据库实例上存储的数据。  - 取值true：删除。 - 取值为空或false：不删除。 默认值为空。

        :param delete_dn_data: The delete_dn_data of this DeleteDdmInstanceRequest.
        :type delete_dn_data: bool
        """
        self._delete_dn_data = delete_dn_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteDdmInstanceRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkddm-3.1.159-py2.py3-none-any.whl: huaweicloudsdkddm/v1/model/delete_ddm_instance_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteDdmInstanceRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instance_id': 'str',
        'delete_dn_data': 'bool'
    }

    attribute_map = {
        'instance_id': 'instance_id',
        'delete_dn_data': 'delete_dn_data'
    }

    def __init__(self, instance_id=None, delete_dn_data=None):
        r"""DeleteDdmInstanceRequest

        The model defined in huaweicloud sdk

        :param instance_id: DDM实例ID。
        :type instance_id: str
        :param delete_dn_data: 是否同时删除关联后端数据库实例上存储的数据。  - 取值true：删除。 - 取值为空或false：不删除。 默认值为空。
        :type delete_dn_data: bool
        """
        
        

        self._instance_id = None
        self._delete_dn_data = None
        self.discriminator = None

        self.instance_id = instance_id
        if delete_dn_data is not None:
            self.delete_dn_data = delete_dn_data

    @property
    def instance_id(self):
        r"""Gets the instance_id of this DeleteDdmInstanceRequest.

        DDM实例ID。

        :return: The instance_id of this DeleteDdmInstanceRequest.
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        r"""Sets the instance_id of this DeleteDdmInstanceRequest.

        DDM实例ID。

        :param instance_id: The instance_id of this DeleteDdmInstanceRequest.
        :type instance_id: str
        """
        self._instance_id = instance_id

    @property
    def delete_dn_data(self):
        r"""Gets the delete_dn_data of this DeleteDdmInstanceRequest.

        是否同时删除关联后端数据库实例上存储的数据。  - 取值true：删除。 - 取值为空或false：不删除。 默认值为空。

        :return: The delete_dn_data of this DeleteDdmInstanceRequest.
        :rtype: bool
        """
        return self._delete_dn_data

    @delete_dn_data.setter
    def delete_dn_data(self, delete_dn_data):
        r"""Sets the delete_dn_data of this DeleteDdmInstanceRequest.

        是否同时删除关联后端数据库实例上存储的数据。  - 取值true：删除。 - 取值为空或false：不删除。 默认值为空。

        :param delete_dn_data: The delete_dn_data of this DeleteDdmInstanceRequest.
        :type delete_dn_data: bool
        """
        self._delete_dn_data = delete_dn_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteDdmInstanceRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
